package com.muyu.edition.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.edition.domain.Config;
import com.muyu.edition.domain.model.TextData;
import com.muyu.edition.domain.resp.EngineConfigResp;
import com.muyu.edition.service.IConfigService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 引擎Controller
 *
 * @author muyu
 * @date 2024-05-04
 */
@RestController
@RequestMapping("/config")
public class ConfigController extends BaseController {
    @Autowired
    private IConfigService configService;

    /**
     * 查询引擎列表
     */
    @RequiresPermissions("system:config:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Config>> list(Config config) {
        startPage();
        List<Config> list = configService.selectConfigList(config);
        return getDataTable(list);
    }

    /**
     * 查询引擎列表
     *
     * @param ruleId
     * @return
     */
    @PostMapping("/listConfigEs/{ruleId}")
    public Result<List<Config>> listConfigEs(@PathVariable Long ruleId) {
        List<Config> list = configService.listConfigEs(ruleId);
        return success(list);
    }

    /**
     * 导出引擎列表
     */
    @RequiresPermissions("system:config:export")
    @Log(title = "引擎", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Config config) {
        List<Config> list = configService.selectConfigList(config);
        ExcelUtil<Config> util = new ExcelUtil<Config>(Config.class);
        util.exportExcel(response, list, "引擎数据");
    }

    /**
     * 获取引擎详细信息
     */
    @RequiresPermissions("system:config:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id) {
        return success(configService.selectConfigById(id));
    }

    /**
     * 新增引擎
     */
    @RequiresPermissions("system:config:add")
    @Log(title = "引擎", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody Config config) {
        return toAjax(configService.insertConfig(config));
    }

    /**
     * 修改引擎
     */
    @RequiresPermissions("system:config:edit")
    @Log(title = "引擎", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody Config config) {
        return toAjax(configService.updateConfig(config));
    }

    /**
     * 删除引擎
     */
    @RequiresPermissions("system:config:remove")
    @Log(title = "引擎", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids) {
        return toAjax(configService.deleteConfigByIds(ids));
    }

    /**
     * 引擎测试
     *
     * @param textData
     * @return
     */
    @PostMapping("/testData")
    public Result<Object> ruleText(@RequestBody TextData textData) {
        return success(configService.testData(textData));
    }

    /**
     * 通过引擎作用域获取引擎配置作用域信息
     *
     * @param id
     * @return
     */
    @PostMapping("getScopeInfo/{id}")
    public Result<EngineConfigResp> getScopeInfo(@PathVariable Integer id) {
        return success(configService.getScopeInfo(id));
    }

    @PostMapping("queryConfigInfo/{ruleId}")
    public Result<List<Config>> queryConfigInfo(@PathVariable Long ruleId) {
        return success(configService.queryConfigInfo(ruleId));
    }
}
